%define anolis_release 1

Name:           nftables
Version:        1.0.8
Release:        %{anolis_release}%{?dist}
Epoch:          1
Summary:        Netfilter Tables userspace utilites

License:        GPLv2
URL:            https://netfilter.org/projects/nftables
Source0:        %{url}/files/%{name}-%{version}.tar.xz
Source1:        nftables.service
Source2:        nftables.conf
Source3:        main.nft
Source4:        router.nft
Source5:        nat.nft

BuildRequires: make gcc automake autoconf
BuildRequires: flex bison systemd asciidoc
BuildRequires: python3-setuptools python3-devel
BuildRequires: iptables-devel readline-devel jansson-devel
BuildRequires: readline-devel libedit-devel gmp-devel
BuildRequires: pkgconfig(libmnl) >= 1.0.4 pkgconfig(libnftnl) >= 1.2.5

Requires: libmnl >= 1.0.4 libnftnl >= 1.2.5

%description
nftables replaces the popular {ip,ip6,arp,eb}tables. This software provides
a new in-kernel packet classification framework that is based on a
network-specific Virtual Machine (VM) and a new nft userspace command line tool.
nftables reuses the existing Netfilter subsystems such as the existing hook
infrastructure, the connection tracking system, NAT, userspace queueing and logging subsystem.

This software also provides libnftables, the high-level userspace library that
includes support for JSON, see man (3)libnftables for more information.

%package devel
Summary:        Development tools for libnftables
Requires:       %{name} = %{EVR}

%description devel
This package provides the development libraries and header files for the libnftables.

%package -n python3-%{name}
Summary:        Python module providing an interface to libnftables
Requires:       %{name} = %{EVR}
%python_provide python3-nftables

%description -n python3-%{name}
This package provides the nftables python module provides an interface to libnftables
via ctypes.

%prep
%autosetup -p1
# prevent setuptools from installing an egg
sed -i 's/--prefix $(DESTDIR)$(prefix)/--root $(DESTDIR) --prefix $(prefix)/' py/Makefile.am

%build
autoreconf -fiv
%configure --disable-silent-rules \
           --with-xtables \
           --with-json \
           --enable-python \
           --with-python-bin=%{__python3} \
           --disable-static
%make_build

%install
%make_install

mkdir -p %{buildroot}%{_unitdir} %{buildroot}%{_sysconfdir}/sysconfig
install -pm 644 %{SOURCE1} %{buildroot}%{_unitdir}/
install -pm 644 %{SOURCE2} %{buildroot}%{_sysconfdir}/sysconfig/

rm -f %{buildroot}%{_datadir}/%{name}/*
for f in %{SOURCE3} %{SOURCE4} %{SOURCE5}; do
	install -pm 600 $f %{buildroot}%{_sysconfdir}/%{name}/
done

find %{buildroot}%{_sysconfdir} -type d -exec chmod 0700 {} \;
find %{buildroot}%{_sysconfdir} -type f -exec chmod 0600 {} \;

sofile=$(readlink %{buildroot}%{_libdir}/libnftables.so)
sed -i -e 's/\(sofile=\)".*"/\1"'$sofile'"/' %{buildroot}%{python3_sitelib}/%{name}/nftables.py

%generate_compatibility_deps

%post
%systemd_post nftables.service

%preun
%systemd_preun nftables.service

%postun
%systemd_postun_with_restart nftables.service

%files
%config(noreplace) %{_sysconfdir}/%{name}
%config(noreplace) %{_sysconfdir}/sysconfig/nftables.conf
%{_sbindir}/nft
%{_libdir}/libnftables.so.1
%{_libdir}/libnftables.so.1.1.0
%{_unitdir}/nftables.service

%dir %{abidir}
%{abidir}/nft-option.list
%{abidir}/libnftables.dump

%{_mandir}/man5/libnftables-json.5*
%{_mandir}/man8/nft*
%{_docdir}/%{name}/examples/*.nft
%license COPYING

%files devel
%{_libdir}/libnftables.so
%{_libdir}/pkgconfig/libnftables.pc
%{_includedir}/nftables/libnftables.h
%{_mandir}/man3/libnftables.3*

%files -n python3-%{name}
%{python3_sitelib}/%{name}-*.egg-info
%{python3_sitelib}/%{name}

%changelog
* Thu Mar 07 2024 Huang Yang <huangyang@loongson.cn> - 1.0.8-1
- New version 1.0.8

* Tue Apr 11 2023 Yuanhong Peng <yummypeng@linux.alibaba.com> - 1.0.7-2
- Refactor the specfile and also fix build error with setuptools

* Tue Mar 14 2023 Funda Wang <fundawang@yeah.net> - 1.0.7-1
- New version 1.0.7

* Mon Jan 2 2023 Funda Wang <fundawang@yeah.net> - 1.0.6-1
- New version 1.0.6

* Tue Oct 18 2022 mgb01105731 <mgb01105731@alibaba-inc.com> - 1.0.1-2
- optimise spec file

* Fri Mar  11 2022 zl01087097 <zl01087097@alibaba-inc.com> - 1.0.1-1
- upstream version 1.0.1
